package com.example.wholeestate.controller;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.example.wholeestate.common.base.BaseController;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.model.PageImg;
import com.example.wholeestate.service.IPageImgService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-03-22
 */
@RestController
@RequestMapping("/")
@Api(value = "首页图片操作API", description = "首页图片操作API")
public class PageImgController extends BaseController {

    @Autowired
    private IPageImgService iPageImgService;
    private IdGen idGen = IdGen.get();

    @ApiOperation(value = "后台首页图片", notes = "后台首页图片")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageNum", value = "pageNum第几页"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = Integer.class, name = "pageSize", value = "pageSize一页多少行"),
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "location",value = "图片位置" ),
    })
    @RequestMapping(value = "/pageImgList", method = RequestMethod.GET)
    public ResponseBean apageImgSelect(
            @RequestParam(defaultValue = "1") Integer pageNum,
            @RequestParam(defaultValue = "10") Integer pageSize,
            @RequestParam(value = "location",required = false)String location) {

        ResponseBean responseBean = iPageImgService.apageImgSelect(pageNum, pageSize, location);
        return responseBean;
    }

    @ApiOperation(value = "后台首页图片", notes = "后台首页图片")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path",dataType = "String",name = "id",value = "主键" ),
    })
    @RequestMapping(value = "/pageImgDetail/{id}", method = RequestMethod.GET)
    public ResponseBean pageImgDetail(@PathVariable(value = "id")String id) {

        ResponseBean responseBean = iPageImgService.pageImgDetail(id);
        return responseBean;
    }

    @RequestMapping(value = "/wx/banner", method = RequestMethod.GET)
    @ApiOperation(value = "微信小程序 首页Banner")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "imgType", value = "图片类型"),
            @ApiImplicitParam(paramType = "query", dataTypeClass = String.class, name = "imgLocation", value = "图片位置")
    })
    public ResponseBean getWxBanner(@RequestParam("imgType") String imgType,
                                    @RequestParam("imgLocation") String imgLocation) {
        ResponseBean responseBean = new ResponseBean();

        QueryWrapper<PageImg> pageImgQueryWrapper = new QueryWrapper<>();
        pageImgQueryWrapper.eq("img_type", imgType);
        pageImgQueryWrapper.eq("img_location", imgLocation);
        pageImgQueryWrapper.eq("status", 1);
        List<PageImg> list = iPageImgService.list(pageImgQueryWrapper);

        responseBean.addSuccess(list);
        return responseBean;
    }

    @ApiOperation(value = "后台添加首页图片", notes = "后台添加首页图片")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "imgLocation图片地址;imgType图片类型;link链接地址;orderNo排序;url:图片地址")
    })
    @RequestMapping(value = "/pageIm/add", method = RequestMethod.POST)
    public ResponseBean pageImAdd(@RequestBody String parameter) {
        ResponseBean responseBean = new ResponseBean();
        PageImg pageimg = JSONObject.parseObject(parameter, PageImg.class);
        pageimg.setStatus(1);
        pageimg.setPageId(idGen.nextId()+"");
        pageimg.setCreateDate(LocalDateTime.now());
        iPageImgService.save(pageimg);
        return responseBean;
    }

    @ApiOperation(value = "后台添加首页图片修改", notes = "后台添加首页图片修改")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "pageId:主键;imgLocation图片地址;imgType图片类型;link链接地址;orderNo排序;url:图片地址")
    })
    @RequestMapping(value = "/pageIm/update", method = RequestMethod.PUT)
    public ResponseBean pageImUpdate(@RequestBody String parameter) {

        ResponseBean responseBean = new ResponseBean();
        PageImg pageimg = JSONObject.parseObject(parameter, PageImg.class);
        QueryWrapper<PageImg> activityQueryWrapper = new QueryWrapper<>();
        activityQueryWrapper.eq("page_id", pageimg.getPageId());
        iPageImgService.update(pageimg, activityQueryWrapper);
        return responseBean;
    }

    @ApiOperation(value = "后台添加首页图片删除", notes = "后台添加首页图片删除")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "Query",dataType = "String",name = "id",value = "id" ),
    })
    @RequestMapping(value = "/pageImg/delete", method = RequestMethod.DELETE)
    public ResponseBean pageImdelect(@RequestParam(value = "id",required = false)String id) {
        ResponseBean responseBean = iPageImgService.pageImdelectDelect(id);
        return responseBean;
    }

}
