package com.example.wholeestate.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.wholeestate.common.resp.ResponseBean;
import com.example.wholeestate.common.uuid.IdGen;
import com.example.wholeestate.dao.CommentImgMapper;
import com.example.wholeestate.dao.CommentMapper;
import com.example.wholeestate.dao.CustomerMapper;
import com.example.wholeestate.model.*;
import com.example.wholeestate.service.ICommentService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 评论表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2019-03-20
 */
@Service
public class CommentServiceImpl extends ServiceImpl<CommentMapper, Comment> implements ICommentService {

    @Autowired
    private CommentMapper commentMapper;

    @Autowired
    private CustomerMapper customerMapper;

    @Autowired
    private CommentImgMapper commentImgMapper;

    private IdGen idGen = IdGen.get();

    @Override
    public ResponseBean addComment(String parameter) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);

        // 评论的图片
        String [] imgArray = jsonObject.getJSONArray("imgArray").toArray(new String[]{});

        Comment comment = jsonObject.toJavaObject(Comment.class);
        comment.setCreateDate(LocalDateTime.now());
        comment.setStatus(1);

        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("customer_id", comment.getCustomerId());
        Customer customer = customerMapper.selectOne(customerQueryWrapper);
        if (null == customer) {
            responseBean.addError("评论用户不存在!");
            return responseBean;
        }

        comment.setCommentId(idGen.nextId()+"");
        comment.setCustomerName(customer.getCustomerName());
        comment.setAvatar(customer.getAvatar());

        int insert = commentMapper.insert(comment);
        if (insert <= 0) {
            responseBean.addError("评论失败!");
            return responseBean;
        }

        // 插入评论
        for (int i =0; i < imgArray.length; i++) {
            CommentImg commentImg = new CommentImg();
            commentImg.setImgId(idGen.nextId() + "");
            commentImg.setCommentId(comment.getCommentId());
            commentImg.setImgUrl(imgArray[i]);
            commentImg.setOrderNo(i);
            commentImg.setStatus(1);

            commentImgMapper.insert(commentImg);
        }


        responseBean.addSuccess("评论成功!");
        return responseBean;
    }

    @Override
    public ResponseBean getCommentList(String commentType, String mainId, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();

        Page<Comment> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);

//        QueryWrapper<Comment> commentQueryWrapper = new QueryWrapper<>();
//        commentQueryWrapper.eq("comment_type", commentType);
//        commentQueryWrapper.eq(StringUtils.isNotBlank(mainId),"main_id", mainId);
        IPage<Map<String, Object>> commentIPage = commentMapper.selectCommentListByType(page, commentType);
//                .selectPage(page, commentQueryWrapper);
        commentIPage.getRecords().forEach(e -> {
            // 查询图片
            QueryWrapper<CommentImg> queryCommentImgWrapper = new QueryWrapper<>();
            queryCommentImgWrapper.eq("comment_id", e.get("comment_id"));
            queryCommentImgWrapper.eq("status", 1);
            queryCommentImgWrapper.orderByAsc("order_no");
            List<CommentImg> commentImgs = commentImgMapper.selectList(queryCommentImgWrapper);
            e.put("img", commentImgs);
        });

        responseBean.addSuccess(commentIPage);
        return responseBean;
    }

    @Override
    public ResponseBean selectCommentInfoId(String commentId) {
        ResponseBean responseBean = new ResponseBean();

        Map<String, Object> comment = commentMapper.selectCommentInfoId(commentId);

            // 查询图片
        QueryWrapper<CommentImg> queryCommentImgWrapper = new QueryWrapper<>();
        queryCommentImgWrapper.eq("comment_id", comment.get("comment_id"));
        queryCommentImgWrapper.eq("status", 1);
        queryCommentImgWrapper.orderByAsc("order_no");
        List<CommentImg> commentImgs = commentImgMapper.selectList(queryCommentImgWrapper);
        comment.put("img", commentImgs);

        QueryWrapper<Comment> childCommentQuery = new QueryWrapper<>();
        childCommentQuery.eq("parent_id", comment.get("comment_id"));
        childCommentQuery.eq("status", 1);
        List<Comment> childComments = commentMapper.selectList(childCommentQuery);
        childComments.forEach(e -> {
            // 查询图片
            QueryWrapper<CommentImg> queryChildCommentImgWrapper = new QueryWrapper<>();
            queryChildCommentImgWrapper.eq("comment_id", e.getCommentId());
            queryChildCommentImgWrapper.eq("status", 1);
            queryChildCommentImgWrapper.orderByAsc("order_no");
            List<CommentImg> childCommentImgs = commentImgMapper.selectList(queryChildCommentImgWrapper);
            e.setCommentImgList(childCommentImgs);
        });
        comment.put("childComment", childComments);

        responseBean.addSuccess(comment);
        return responseBean;
    }

    @Override
    public ResponseBean getWxCommentList(String commentType, String mainId, Integer pageNum, Integer pageSize) {
        ResponseBean responseBean = new ResponseBean();

        Page<Comment> page = new Page<>();
        page.setCurrent(pageNum);
        page.setSize(pageSize);

        QueryWrapper<Comment> commentQueryWrapper = new QueryWrapper<>();
        commentQueryWrapper.eq("comment_type", commentType);
        commentQueryWrapper.eq("main_id", mainId);
        IPage<Comment> commentIPage = commentMapper.selectPage(page, commentQueryWrapper);
        List<Comment> records = commentIPage.getRecords();
        records.forEach(e -> {
            QueryWrapper<Comment> childCommentQuery = new QueryWrapper<>();
            childCommentQuery.eq("parent_id", e.getCommentId());
            childCommentQuery.eq("status", 1);
            List<Comment> comments = commentMapper.selectList(childCommentQuery);
            e.setChildComment(comments);

            // 查询图片
            QueryWrapper<CommentImg> queryCommentImgWrapper = new QueryWrapper<>();
            queryCommentImgWrapper.eq("comment_id", e.getCommentId());
            queryCommentImgWrapper.eq("status", 1);
            queryCommentImgWrapper.orderByAsc("order_no");
            List<CommentImg> commentImgs = commentImgMapper.selectList(queryCommentImgWrapper);
            e.setCommentImgList(commentImgs);
        });

        responseBean.addSuccess(commentIPage);
        return responseBean;
    }

    @Override
    public ResponseBean addWxComment(String openid, String parameter) {
        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);

        // 评论的图片
        String [] imgArray = jsonObject.getJSONArray("imgArray").toArray(new String[]{});

        Comment comment = jsonObject.toJavaObject(Comment.class);
        comment.setCreateDate(LocalDateTime.now());
        comment.setStatus(1);

        QueryWrapper<Customer> customerQueryWrapper = new QueryWrapper<>();
        customerQueryWrapper.eq("openid", openid);
        Customer customer = customerMapper.selectOne(customerQueryWrapper);
        if (null == customer) {
            responseBean.addError("评论用户不存在!");
            return responseBean;
        }

        comment.setCommentId(idGen.nextId()+"");
        comment.setCustomerName(customer.getCustomerName());
        comment.setAvatar(customer.getAvatar());
        comment.setCustomerId(customer.getCustomerId());

        int insert = commentMapper.insert(comment);
        if (insert <= 0) {
            responseBean.addError("评论失败!");
            return responseBean;
        }

        // 插入评论
        for (int i =0; i < imgArray.length; i++) {
            CommentImg commentImg = new CommentImg();
            commentImg.setImgId(idGen.nextId() + "");
            commentImg.setCommentId(comment.getCommentId());
            commentImg.setImgUrl(imgArray[i]);
            commentImg.setOrderNo(i);
            commentImg.setStatus(1);

            commentImgMapper.insert(commentImg);
        }

        responseBean.addSuccess("评论成功!");
        return responseBean;
    }
}
